# TuxRun - easily test Linux on QEMU

TuxRun, by [Linaro](https://www.linaro.org/), is a command line tool for
testing Linux on QEMU, using curated test suites.  TuxRun is a part of
[TuxSuite](https://tuxsuite.com), a suite of tools and services to help with
Linux kernel development.
